@@ -9,7 +9,6 @@
 
 class Constants;
 class QButtonGroup;
-class QLabel;
 class KToggleAction;
 class KCalcConstMenu;
 class KCalcStatusBar;
@@ -48,7 +47,6 @@ class KCalcStatusBar;
 #include "ui_kcalc.h"
 
 #include <QQueue>
-#include <array>
 #include <kxmlguiwindow.h>
 
 class General : public QWidget, public Ui::General
@@ -241,7 +239,7 @@ protected Q_SLOTS:
     void slotChooseScientificConst4(const science_constant &);
     void slotChooseScientificConst5(const science_constant &);
 
-    void slotBitsetChanged(quint64);
+    void slotBitsetChanged(qint64 value);
     void slotUpdateBitset(const KNumber &);
 
     void slotBaseModeAmountChanged(const KNumber &number);
