@@ -11,7 +11,13 @@
 #include <QMenu>
 #include <QString>
 
-enum ConstantCategory { Mathematics = 1, Electromagnetic = 2, Nuclear = 4, Thermodynamics = 8, Gravitation = 16 };
+enum ConstantCategory {
+    Mathematics = 1,
+    Electromagnetic = 2,
+    Nuclear = 4,
+    Thermodynamics = 8,
+    Gravitation = 16
+};
 
 struct science_constant {
     QString label;
